==> keyclic_sdk_api-1.39.1.tar.gz: lib/model/feedback_review_request_links_organization.dart <==
part of keyclic_sdk_api.api;

class FeedbackReviewRequestLinksOrganization {
  /* The URI of the organization associated to the given feedbackreviewrequest. */
  String href = null;

  CategoryLinksOrganizationIriTemplate iriTemplate = null;

  FeedbackReviewRequestLinksOrganization({
    this.href,
    this.iriTemplate,
  });

  @override
  String toString() {
    return 'FeedbackReviewRequestLinksOrganization[href=$href, iriTemplate=$iriTemplate, ]';
  }

  FeedbackReviewRequestLinksOrganization.fromJson(Map<String, dynamic> json) {
    if (json == null) return;
    href = json['href'];
    iriTemplate =
        new CategoryLinksOrganizationIriTemplate.fromJson(json['iriTemplate']);
  }

  Map<String, dynamic> toJson() {
    return {
      'href': href,
      'iriTemplate': iriTemplate,
    };
  }

  static List<FeedbackReviewRequestLinksOrganization> listFromJson(
      List<dynamic> json) {
    return json == null
        ? new List<FeedbackReviewRequestLinksOrganization>()
        : json
            .map((value) =>
                new FeedbackReviewRequestLinksOrganization.fromJson(value))
            .toList();
  }

  static Map<String, FeedbackReviewRequestLinksOrganization> mapFromJson(
      Map<String, dynamic> json) {
    var map = new Map<String, FeedbackReviewRequestLinksOrganization>();
    if (json != null && json.length > 0) {
      json.forEach((String key, dynamic value) => map[key] =
          new FeedbackReviewRequestLinksOrganization.fromJson(value));
    }
    return map;
  }
}

==> keyclic_sdk_api-1.39.4.tar.gz: lib/model/feedback_review_request_links_organization.dart <==
part of keyclic_sdk_api.api;

class FeedbackReviewRequestLinksOrganization {
  FeedbackReviewRequestLinksOrganization({
    this.href,
    this.iriTemplate,
  });

  FeedbackReviewRequestLinksOrganization.fromJson(Map<String, dynamic> json) {
    if (json == null) {
      return;
    }
    href = json['href'];
    iriTemplate =
        CategoryLinksOrganizationIriTemplate.fromJson(json['iriTemplate']);
  }

  /* The URI of the organization associated to the given feedbackreviewrequest. */
  String href;

  CategoryLinksOrganizationIriTemplate iriTemplate;

  Map<String, dynamic> toJson() {
    return {
      'href': href,
      'iriTemplate': iriTemplate,
    };
  }

  @override
  String toString() {
    return 'FeedbackReviewRequestLinksOrganization[href=$href, iriTemplate=$iriTemplate, ]';
  }

  static List<FeedbackReviewRequestLinksOrganization> listFromJson(
      List<dynamic> json) {
    return json == null
        ? List<FeedbackReviewRequestLinksOrganization>()
        : json
            .map((value) =>
                FeedbackReviewRequestLinksOrganization.fromJson(value))
            .toList();
  }

  static Map<String, FeedbackReviewRequestLinksOrganization> mapFromJson(
      Map<String, dynamic> json) {
    var map = Map<String, FeedbackReviewRequestLinksOrganization>();
    if (json != null && json.isNotEmpty) {
      json.forEach((String key, dynamic value) =>
          map[key] = FeedbackReviewRequestLinksOrganization.fromJson(value));
    }
    return map;
  }
}
